==> zio-aws-ec2_2.12-6.20.78.3-sources.jar: zio/aws/ec2/model/CancelImageLaunchPermissionRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ImageId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CancelImageLaunchPermissionRequest(imageId: ImageId) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest = {
    import CancelImageLaunchPermissionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
      .builder()
      .imageId(ImageId.unwrap(imageId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CancelImageLaunchPermissionRequest.ReadOnly =
    zio.aws.ec2.model.CancelImageLaunchPermissionRequest.wrap(buildAwsValue())
}
object CancelImageLaunchPermissionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CancelImageLaunchPermissionRequest =
      zio.aws.ec2.model.CancelImageLaunchPermissionRequest(imageId)
    def imageId: ImageId
    def getImageId: ZIO[Any, Nothing, ImageId] = ZIO.succeed(imageId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
  ) extends zio.aws.ec2.model.CancelImageLaunchPermissionRequest.ReadOnly {
    override val imageId: ImageId =
      zio.aws.ec2.model.primitives.ImageId(impl.imageId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
  ): zio.aws.ec2.model.CancelImageLaunchPermissionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/CancelImageLaunchPermissionRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ImageId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CancelImageLaunchPermissionRequest(
    imageId: ImageId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest = {
    import CancelImageLaunchPermissionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
      .builder()
      .imageId(ImageId.unwrap(imageId): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CancelImageLaunchPermissionRequest.ReadOnly =
    zio.aws.ec2.model.CancelImageLaunchPermissionRequest.wrap(buildAwsValue())
}
object CancelImageLaunchPermissionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CancelImageLaunchPermissionRequest =
      zio.aws.ec2.model
        .CancelImageLaunchPermissionRequest(imageId, dryRun.map(value => value))
    def imageId: ImageId
    def dryRun: Optional[Boolean]
    def getImageId: ZIO[Any, Nothing, ImageId] = ZIO.succeed(imageId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
  ) extends zio.aws.ec2.model.CancelImageLaunchPermissionRequest.ReadOnly {
    override val imageId: ImageId =
      zio.aws.ec2.model.primitives.ImageId(impl.imageId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CancelImageLaunchPermissionRequest
  ): zio.aws.ec2.model.CancelImageLaunchPermissionRequest.ReadOnly =
    new Wrapper(impl)
}
